@@ -1,5 +1,7 @@
 package AnyEvent::Impl::Coro;
 
+no warnings;
+
 use base AnyEvent::Impl::Event;
 
 use Coro::Event ();
@@ -9,7 +11,5 @@ sub condvar {
    new Coro::Signal
 }
 
-$AnyEvent::MODEL = __PACKAGE__;
-
 1
 
